@@ -1,5 +1,5 @@
-from ..utils.fs import Path
-from . import File
+from hatch.template import File
+from hatch.utils.fs import Path
 
 
 class CommandLinePackage(File):
@@ -28,22 +28,29 @@ jobs:
       fail-fast: false
       matrix:
         os: [ubuntu-latest, windows-latest, macos-latest]
-        python-version: ['3.7', '3.8', '3.9', '3.10']
+        python-version: ['3.8', '3.9', '3.10', '3.11', '3.12', '3.13']
 
     steps:
-    - uses: actions/checkout@v2
+    - uses: actions/checkout@v3
 
     - name: Set up Python ${{ matrix.python-version }}
-      uses: actions/setup-python@v3
+      uses: actions/setup-python@v4
       with:
         python-version: ${{ matrix.python-version }}
 
     - name: Install Hatch
       run: pip install --upgrade hatch
 
-    - name: Run tests
-      run: hatch run cov
-"""  # noqa: E501
+    - name: Run static analysis
+      run: hatch fmt --check
 
-    def __init__(self, template_config: dict, plugin_config: dict):
+    - name: Run tests
+      run: hatch test --python ${{ matrix.python-version }} --cover --randomize --parallel --retries 2 --retry-delay 1
+"""
+
+    def __init__(
+        self,
+        template_config: dict,  # noqa: ARG002
+        plugin_config: dict,  # noqa: ARG002
+    ):
         super().__init__(Path('.github', 'workflows', 'test.yml'), self.TEMPLATE)
