@@ -1,7 +1,7 @@
 import os
 
 from hatch.project.core import Project
-from hatchling.utils.constants import DEFAULT_CONFIG_FILE
+from hatchling.utils.constants import DEFAULT_BUILD_SCRIPT, DEFAULT_CONFIG_FILE
 
 
 def test_incompatible_environment(hatch, temp_dir, helpers):
@@ -22,6 +22,19 @@ def test_incompatible_environment(hatch, temp_dir, helpers):
         project, 'default', {'skip-install': True, 'python': '9000', **project.config.envs['default']}
     )
 
+    build_script = path / DEFAULT_BUILD_SCRIPT
+    build_script.write_text(
+        helpers.dedent(
+            """
+            from hatchling.metadata.plugin.interface import MetadataHookInterface
+
+            class CustomMetadataHook(MetadataHookInterface):
+                def update(self, metadata):
+                    pass
+            """
+        )
+    )
+
     with path.as_cwd():
         result = hatch('dep', 'show', 'requirements')
 
