@@ -3,7 +3,7 @@ from hatch.utils.fs import Path
 from hatchling.__about__ import __version__
 from hatchling.metadata.spec import DEFAULT_METADATA_VERSION
 
-from ..new.default import get_files as get_template_files
+from ..new.feature_no_src_layout import get_files as get_template_files
 from .utils import update_record_file_contents
 
 
@@ -21,9 +21,9 @@ def get_files(**kwargs):
 
         files.append(f)
 
-    files.append(File(Path(shared_data_directory, 'data', 'foo.txt'), ''))
-    files.append(File(Path(shared_data_directory, 'data', 'nested', 'bar.txt'), ''))
-    files.append(
+    files.extend((
+        File(Path(shared_data_directory, 'data', 'foo.txt'), ''),
+        File(Path(shared_data_directory, 'data', 'nested', 'bar.txt'), ''),
         File(
             Path(metadata_directory, 'WHEEL'),
             f"""\
@@ -32,9 +32,7 @@ Generator: hatchling {__version__}
 Root-Is-Purelib: true
 Tag: py3-none-any
 """,
-        )
-    )
-    files.append(
+        ),
         File(
             Path(metadata_directory, 'METADATA'),
             f"""\
@@ -44,8 +42,8 @@ Version: 0.0.1
 License-File: LICENSE.txt
 Requires-Python: >3
 """,
-        )
-    )
+        ),
+    ))
 
     record_file = File(Path(metadata_directory, 'RECORD'), '')
     update_record_file_contents(record_file, files)
